@@ -4,9 +4,13 @@ use warnings;
   
 
 sub register_commands {
-  return ( eval => { sub => \&DB::eval, record => 0 } )
+  return (
+    eval => { sub => \&DB::eval, record => 1 },
+    yaml => { sub => \&DB::yaml },
+  );
 }
 
+
 package DB;
 
 # there appears to be something semi-magical about the DB 
@@ -24,4 +28,17 @@ sub eval {
   }
 }
 
+sub yaml {
+  my($req, $context) = @_;
+  my $eval = $req->{yaml};
+  local $SIG{__WARN__} = sub {};
+
+  my $v = eval "package $context->{package}; use YAML; Dump($eval)";
+  if ($@) {
+    return { yaml => $@ };
+  } else {
+    return { yaml => $v };
+  }
+}
+
 1;
